import 'package:flutter/material.dart';

/// PathNavigatingText - Wraps a Text in a Navigation
class PathNavigatingText extends StatelessWidget {
  PathNavigatingText(
      {@required this.text,
      @required this.path,
      @required this.textStyle,
      this.textColor = Colors.white,
      this.textAlignment = Alignment.center,
      this.replacing = false,
      this.keepAllPriorRoutes = false});

  final TextStyle textStyle;
  final bool replacing;
  final String path;
  final Color textColor;
  final Alignment textAlignment;
  final String text;
  final bool keepAllPriorRoutes;

  @override
  Widget build(BuildContext context) {
    return DefaultTextStyle(
      style: textStyle,
      child: GestureDetector(
        onTap: () {
          if (replacing) {
            Navigator.of(context).pushNamedAndRemoveUntil(
                path, (Route<dynamic> route) => keepAllPriorRoutes);
          } else {
            Navigator.of(context).pushNamed(path);
          }
        },
        child: Container(
          color: textColor,
          alignment: textAlignment,
          child: Text(text),
        ),
      ),
    );
  }
}
